### Name: baymvb
### Title: Bayesian analysis of multivariate binary data
### Aliases: baymvb
### Keywords: models

### ** Examples

library(baymvb) # load library
data(teeth4)   # simulated 4-teeth data
names(teeth4)

# a: Multivariate probit
out.mvprobit <- baymvb(formula=y~ factor(tooth) + gender + age,data=teeth4, 
                        nvars=4,burnin = 1000, mcmc = 2000, refresh=250,distr="mvprobit")
out.mvprobit # summary(out.mvprobit)
# compare with GLM
fit.probit <- glm(y~ factor(tooth) + gender + age,family=binomial(probit),data=teeth4)
cbind(mvprobit=colMeans(out.mvprobit$samples)[1:6],glm.probit=fit.probit$coeff)

# b: Multivariate t-link
out.mvt      <- baymvb(formula=y~ factor(tooth) + gender + age,data=teeth4, 
                        nvars=4,burnin = 1000, mcmc = 2000, refresh=250,distr="mvt")
out.mvt # summary(out.mvt)                      
# compare with GLM
fit.logit <- glm(y~ factor(tooth) + gender + age,family=binomial(logit),data=teeth4)
cbind(mvt=colMeans(out.mvt$samples)[1:6],glm.logit=fit.logit$coeff)

# correlation matrix from a vector of unique elements of R
R.mvprobit <- xpndCor(out.mvprobit)
R.mvprobit

R.mvt <- xpndCor(out.mvt)
R.mvt


# Density plots
par(mfrow=c(2,2))
densPlot(out.mvprobit,5,main="Gender(mvprobit)")
densPlot(out.mvprobit,6,main="Age(mvprobit)")
densPlot(out.mvt,5,main="Gender(mvt)")
densPlot(out.mvt,6,main="Age(mvt)")

# Trace plots
par(mfrow=c(2,2))
tracePlot(out.mvprobit,5,main="Gender(mvprobit)")
tracePlot(out.mvprobit,6,main="Age(mvprobit)")
tracePlot(out.mvt,5,main="Gender(mvt)")
tracePlot(out.mvt,6,main="Age(mvt)")




